# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbc
from __future__ import annotations
import typing
from abc import abstractproperty
from .connection_properties import ConnectionProperties as ConnectionProperties_1a9f0ee1
if typing.TYPE_CHECKING:
    from ..beans.named_value import NamedValue as NamedValue_a37a0af3

class JDBCConnectionProperties(ConnectionProperties_1a9f0ee1):
    """
    Service Class

    represents the properties for a JDBC connection (session) with a specific database.
    
    These properties can be used when calling the method com.sun.star.sdbc.XDriver.connect() or com.sun.star.sdbc.XDriverManager.getConnectionWithInfo().
    
    The properties for a connection contain additional information about how to connect to a database and how to control the behavior of the resulting connection should be.
    
    **since**
    
        OOo 2.3

    See Also:
        `API JDBCConnectionProperties <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdbc_1_1JDBCConnectionProperties.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbc'
    __ooo_full_ns__: str = 'com.sun.star.sdbc.JDBCConnectionProperties'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def SystemProperties(self) -> typing.Tuple[NamedValue_a37a0af3, ...]:
        """
        specifies a set of properties to pass to java.lang.System.setProperty before loading the system's JDBC driver.
        """
        ...

    @abstractproperty
    def TypeInfoSettings(self) -> typing.Tuple[object, ...]:
        """
        specifies how the type info returned by com.sun.star.sdbc.XDatabaseMetaData.getTypeInfo() will be modified.
        
        The sequence contains an even amount of string values. Each pair describes what should be searched for and what should be replaced if found. The syntax is:
        
        COLUMN(X) defines the column which will be compared and the column which will be replaced. In the example above column 2 will be compared with the value -5. If this is true than column 6 will now return the value PRECISION.
        """
        ...

    @abstractproperty
    def AutoRetrievingStatement(self) -> str:
        """
        specifies the statement which should be executed when asking an \"INSERT\" statement for the XGeneratedResultSet (future concept) interface.
        """
        ...

    @abstractproperty
    def IsAutoRetrievingEnabled(self) -> bool:
        """
        specifies if retrieving of auto generated values should be enabled or not.
        
        If TRUE than the statement will support the XGeneratedResultSet (future concept) interface, otherwise not.
        """
        ...

    @abstractproperty
    def JavaDriverClass(self) -> str:
        """
        which JDBC driver class should be loaded to create the connection.
        """
        ...

    @abstractproperty
    def JavaDriverClassPath(self) -> str:
        """
        an optional class path to locate the com.sun.star.sdbc.JDBCConnectionProperties.JavaDriverClass
        
        The class path is a list of zero or more internal (see the com.sun.star.uri.ExternalUriReferenceTranslator service) URI references, where any space characters (U+0020) are ignored (and, in particular, separate adjacent URI references). Any “vnd.sun.star.expand” URL references in the list are expanded using the com.sun.star.util.theMacroExpander singleton.
        
        **since**
        
            OOo 2.3
        """
        ...


__all__ = ['JDBCConnectionProperties']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.rendering
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .color_component import ColorComponent as ColorComponent_e4c0e78


class RGBColor(object):
    """
    Struct Class

    RGB color triplet.

    See Also:
        `API RGBColor <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1rendering_1_1RGBColor.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.RGBColor'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.rendering.RGBColor'
    """Literal Constant ``com.sun.star.rendering.RGBColor``"""

    def __init__(self, Red: typing.Optional[ColorComponent_e4c0e78] = ColorComponent_e4c0e78(0.0), Green: typing.Optional[ColorComponent_e4c0e78] = ColorComponent_e4c0e78(0.0), Blue: typing.Optional[ColorComponent_e4c0e78] = ColorComponent_e4c0e78(0.0)) -> None:
        """
        Constructor

        Arguments:
            Red (ColorComponent, optional): Red value.
            Green (ColorComponent, optional): Green value.
            Blue (ColorComponent, optional): Blue value.
        """
        super().__init__()

        if isinstance(Red, RGBColor):
            oth: RGBColor = Red
            self.Red = oth.Red
            self.Green = oth.Green
            self.Blue = oth.Blue
            return

        kargs = {
            "Red": Red,
            "Green": Green,
            "Blue": Blue,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._red = kwargs["Red"]
        self._green = kwargs["Green"]
        self._blue = kwargs["Blue"]


    @property
    def Red(self) -> ColorComponent_e4c0e78:
        """
        Red component. Valid range is [0,1.0].
        """
        return self._red

    @Red.setter
    def Red(self, value: ColorComponent_e4c0e78) -> None:
        self._red = value

    @property
    def Green(self) -> ColorComponent_e4c0e78:
        """
        Green component. Valid range is [0,1.0].
        """
        return self._green

    @Green.setter
    def Green(self, value: ColorComponent_e4c0e78) -> None:
        self._green = value

    @property
    def Blue(self) -> ColorComponent_e4c0e78:
        """
        Blue component. Valid range is [0,1.0].
        """
        return self._blue

    @Blue.setter
    def Blue(self, value: ColorComponent_e4c0e78) -> None:
        self._blue = value


__all__ = ['RGBColor']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73

class XStorable(XInterface_8f010a43):
    """
    offers a simple way to store a component to a URL.
    
    It is usually only useful for two cases:

    See Also:
        `API XStorable <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XStorable.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.XStorable'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.frame.XStorable'

    @abstractmethod
    def getLocation(self) -> str:
        """
        After XStorable.storeAsURL() it returns the URL the object was stored to.
        """
        ...
    @abstractmethod
    def hasLocation(self) -> bool:
        """
        The object may know the location because it was loaded from there, or because it is stored there.
        """
        ...
    @abstractmethod
    def isReadonly(self) -> bool:
        """
        It is not possible to call XStorable.store() successfully when the data store is read-only.
        """
        ...
    @abstractmethod
    def store(self) -> None:
        """
        stores the data to the URL from which it was loaded.
        
        Only objects which know their locations can be stored.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def storeAsURL(self, sURL: str, lArguments: typing.Tuple[PropertyValue_c9610c73, ...]) -> None:
        """
        stores the object's persistent data to a URL and makes this URL the new location of the object.
        
        This is the normal behavior for UI's \"save-as\" feature.
        
        The change of the location makes it necessary to store the document in a format that the object can load. For this reason the implementation of XStorable.storeAsURL() will throw an exception if a pure export filter is used, it will accept only combined import/export filters. For such filters the method XStorable.storeToURL() must be used that does not change the location of the object.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def storeToURL(self, sURL: str, lArguments: typing.Tuple[PropertyValue_c9610c73, ...]) -> None:
        """
        stores the object's persistent data to a URL and continues to be a representation of the old URL.
        
        This is the normal behavior for UI's export feature.
        
        This method accepts all kinds of export filters, not only combined import/export filters because it implements an exporting capability, not a persistence capability.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
        ...

__all__ = ['XStorable']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.animations


class TransitionSubType(object):
    """
    Const Class


    See Also:
        `API TransitionSubType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1animations_1_1TransitionSubType.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.animations'
    __ooo_full_ns__: str = 'com.sun.star.animations.TransitionSubType'
    __ooo_type_name__: str = 'const'

    DEFAULT = 0
    LEFTTORIGHT = 1
    TOPTOBOTTOM = 2
    TOPLEFT = 3
    TOPRIGHT = 4
    BOTTOMRIGHT = 5
    BOTTOMLEFT = 6
    TOPCENTER = 7
    RIGHTCENTER = 8
    BOTTOMCENTER = 9
    LEFTCENTER = 10
    CORNERSIN = 11
    CORNERSOUT = 12
    VERTICAL = 13
    HORIZONTAL = 14
    DIAGONALBOTTOMLEFT = 15
    DIAGONALTOPLEFT = 16
    DOUBLEBARNDOOR = 17
    DOUBLEDIAMOND = 18
    DOWN = 19
    LEFT = 20
    UP = 21
    RIGHT = 22
    RECTANGLE = 25
    DIAMOND = 26
    CIRCLE = 27
    FOURPOINT = 28
    FIVEPOINT = 29
    SIXPOINT = 30
    HEART = 31
    KEYHOLE = 32
    CLOCKWISETWELVE = 33
    CLOCKWISETHREE = 34
    CLOCKWISESIX = 35
    CLOCKWISENINE = 36
    TWOBLADEVERTICAL = 37
    TWOBLADEHORIZONTAL = 38
    FOURBLADE = 39
    CLOCKWISETOP = 40
    CLOCKWISERIGHT = 41
    CLOCKWISEBOTTOM = 42
    CLOCKWISELEFT = 43
    CLOCKWISETOPLEFT = 44
    COUNTERCLOCKWISEBOTTOMLEFT = 45
    CLOCKWISEBOTTOMRIGHT = 46
    COUNTERCLOCKWISETOPRIGHT = 47
    CENTERTOP = 48
    CENTERRIGHT = 49
    TOP = 50
    BOTTOM = 52
    FANOUTVERTICAL = 54
    FANOUTHORIZONTAL = 55
    FANINVERTICAL = 56
    FANINHORIZONTAL = 57
    PARALLELVERTICAL = 58
    PARALLELDIAGONAL = 59
    OPPOSITEVERTICAL = 60
    OPPOSITEHORIZONTAL = 61
    PARALLELDIAGONALTOPLEFT = 62
    PARALLELDIAGONALBOTTOMLEFT = 63
    TOPLEFTHORIZONTAL = 64
    TOPLEFTDIAGONAL = 65
    TOPRIGHTDIAGONAL = 66
    BOTTOMRIGHTDIAGONAL = 67
    BOTTOMLEFTDIAGONAL = 68
    TOPLEFTCLOCKWISE = 69
    TOPRIGHTCLOCKWISE = 70
    BOTTOMRIGHTCLOCKWISE = 71
    BOTTOMLEFTCLOCKWISE = 72
    TOPLEFTCOUNTERCLOCKWISE = 73
    TOPRIGHTCOUNTERCLOCKWISE = 74
    BOTTOMRIGHTCOUNTERCLOCKWISE = 75
    BOTTOMLEFTCOUNTERCLOCKWISE = 76
    VERTICALTOPSAME = 77
    VERTICALBOTTOMSAME = 78
    VERTICALTOPLEFTOPPOSITE = 79
    VERTICALBOTTOMLEFTOPPOSITE = 80
    HORIZONTALLEFTSAME = 81
    HORIZONTALRIGHTSAME = 82
    HORIZONTALTOPLEFTOPPOSITE = 83
    HORIZONTALTOPRIGHTOPPOSITE = 84
    DIAGONALBOTTOMLEFTOPPOSITE = 85
    DIAGONALTOPLEFTOPPOSITE = 86
    TWOBOXTOP = 87
    TWOBOXBOTTOM = 88
    TWOBOXLEFT = 89
    TWOBOXRIGHT = 90
    FOURBOXVERTICAL = 91
    FOURBOXHORIZONTAL = 92
    VERTICALLEFT = 93
    VERTICALRIGHT = 94
    HORIZONTALLEFT = 95
    HORIZONTALRIGHT = 96
    FROMLEFT = 97
    FROMTOP = 98
    FROMRIGHT = 99
    FROMBOTTOM = 100
    CROSSFADE = 101
    FADETOCOLOR = 102
    FADEFROMCOLOR = 103
    FADEOVERCOLOR = 104
    THREEBLADE = 105
    EIGHTBLADE = 106
    ONEBLADE = 107
    ACROSS = 108
    TOPLEFTVERTICAL = 109
    COMBHORIZONTAL = 110
    COMBVERTICAL = 111
    IN = 112
    OUT = 113
    ROTATEIN = 114
    ROTATEOUT = 115
    FROMTOPLEFT = 116
    FROMTOPRIGHT = 117
    FROMBOTTOMLEFT = 118
    FROMBOTTOMRIGHT = 119

__all__ = ['TransitionSubType']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.io.already_connected_exception import AlreadyConnectedException as AlreadyConnectedException
from ...lo.io.buffer_size_exceeded_exception import BufferSizeExceededException as BufferSizeExceededException
from ...lo.io.connect_exception import ConnectException as ConnectException
from ...lo.io.data_input_stream import DataInputStream as DataInputStream
from ...lo.io.data_output_stream import DataOutputStream as DataOutputStream
from ...lo.io.data_transfer_event import DataTransferEvent as DataTransferEvent
from ...lo.io.file_permission import FilePermission as FilePermission
from ...lo.io.io_exception import IOException as IOException
from ...lo.io.markable_input_stream import MarkableInputStream as MarkableInputStream
from ...lo.io.markable_output_stream import MarkableOutputStream as MarkableOutputStream
from ...lo.io.no_route_to_host_exception import NoRouteToHostException as NoRouteToHostException
from ...lo.io.not_connected_exception import NotConnectedException as NotConnectedException
from ...lo.io.object_input_stream import ObjectInputStream as ObjectInputStream
from ...lo.io.object_output_stream import ObjectOutputStream as ObjectOutputStream
from ...lo.io.pipe import Pipe as Pipe
from ...lo.io.pump import Pump as Pump
from ...lo.io.sequence_input_stream import SequenceInputStream as SequenceInputStream
from ...lo.io.sequence_output_stream import SequenceOutputStream as SequenceOutputStream
from ...lo.io.socket_exception import SocketException as SocketException
from ...lo.io.temp_file import TempFile as TempFile
from ...lo.io.text_input_stream import TextInputStream as TextInputStream
from ...lo.io.text_output_stream import TextOutputStream as TextOutputStream
from ...lo.io.unexpected_eof_exception import UnexpectedEOFException as UnexpectedEOFException
from ...lo.io.unknown_host_exception import UnknownHostException as UnknownHostException
from ...lo.io.wrong_format_exception import WrongFormatException as WrongFormatException
from ...lo.io.x_active_data_control import XActiveDataControl as XActiveDataControl
from ...lo.io.x_active_data_sink import XActiveDataSink as XActiveDataSink
from ...lo.io.x_active_data_source import XActiveDataSource as XActiveDataSource
from ...lo.io.x_active_data_streamer import XActiveDataStreamer as XActiveDataStreamer
from ...lo.io.x_async_output_monitor import XAsyncOutputMonitor as XAsyncOutputMonitor
from ...lo.io.x_connectable import XConnectable as XConnectable
from ...lo.io.x_data_exporter import XDataExporter as XDataExporter
from ...lo.io.x_data_importer import XDataImporter as XDataImporter
from ...lo.io.x_data_input_stream import XDataInputStream as XDataInputStream
from ...lo.io.x_data_output_stream import XDataOutputStream as XDataOutputStream
from ...lo.io.x_data_transfer_event_listener import XDataTransferEventListener as XDataTransferEventListener
from ...lo.io.x_input_stream import XInputStream as XInputStream
from ...lo.io.x_input_stream_provider import XInputStreamProvider as XInputStreamProvider
from ...lo.io.x_markable_stream import XMarkableStream as XMarkableStream
from ...lo.io.x_object_input_stream import XObjectInputStream as XObjectInputStream
from ...lo.io.x_object_output_stream import XObjectOutputStream as XObjectOutputStream
from ...lo.io.x_output_stream import XOutputStream as XOutputStream
from ...lo.io.x_persist import XPersist as XPersist
from ...lo.io.x_persist_object import XPersistObject as XPersistObject
from ...lo.io.x_pipe import XPipe as XPipe
from ...lo.io.x_seekable import XSeekable as XSeekable
from ...lo.io.x_seekable_input_stream import XSeekableInputStream as XSeekableInputStream
from ...lo.io.x_sequence_output_stream import XSequenceOutputStream as XSequenceOutputStream
from ...lo.io.x_stream import XStream as XStream
from ...lo.io.x_stream_listener import XStreamListener as XStreamListener
from ...lo.io.x_temp_file import XTempFile as XTempFile
from ...lo.io.x_text_input_stream import XTextInputStream as XTextInputStream
from ...lo.io.x_text_input_stream2 import XTextInputStream2 as XTextInputStream2
from ...lo.io.x_text_output_stream import XTextOutputStream as XTextOutputStream
from ...lo.io.x_text_output_stream2 import XTextOutputStream2 as XTextOutputStream2
from ...lo.io.x_truncate import XTruncate as XTruncate
from ...lo.io.xxml_extractor import XXMLExtractor as XXMLExtractor



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.beans
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class StringPair(object):
    """
    Struct Class

    specifies a pair of two strings.

    See Also:
        `API StringPair <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1beans_1_1StringPair.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.beans'
    __ooo_full_ns__: str = 'com.sun.star.beans.StringPair'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.beans.StringPair'
    """Literal Constant ``com.sun.star.beans.StringPair``"""

    def __init__(self, First: typing.Optional[str] = '', Second: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            First (str, optional): First value.
            Second (str, optional): Second value.
        """
        super().__init__()

        if isinstance(First, StringPair):
            oth: StringPair = First
            self.First = oth.First
            self.Second = oth.Second
            return

        kargs = {
            "First": First,
            "Second": Second,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._first = kwargs["First"]
        self._second = kwargs["Second"]


    @property
    def First(self) -> str:
        """
        specifies the first of the two strings.
        """
        return self._first

    @First.setter
    def First(self, value: str) -> None:
        self._first = value

    @property
    def Second(self) -> str:
        """
        specifies the second of the two strings.
        """
        return self._second

    @Second.setter
    def Second(self, value: str) -> None:
        self._second = value


__all__ = ['StringPair']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form.component
from __future__ import annotations
from abc import abstractproperty
from ..form_component import FormComponent as FormComponent_bc700c03

class HiddenControl(FormComponent_bc700c03):
    """
    Service Class

    This service specifies the model of a hidden control.
    
    The only sense of a hidden control is to store data in the form which is not visible to the user.
    
    Usually, hidden controls are used in com.sun.star.form.component.HTMLForms, where they contain data which is to be submitted.Nevertheless, you can use them in your own forms for storing any data, for instance to evaluate it in some scripting macro.

    See Also:
        `API HiddenControl <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1component_1_1HiddenControl.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form.component'
    __ooo_full_ns__: str = 'com.sun.star.form.component.HiddenControl'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def HiddenValue(self) -> str:
        """
        specifies the value of the component.
        """
        ...


__all__ = ['HiddenControl']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.scanner
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class ScannerContext(object):
    """
    Struct Class

    a scanner context is an identifier for a specific scanner device

    See Also:
        `API ScannerContext <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1scanner_1_1ScannerContext.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.scanner'
    __ooo_full_ns__: str = 'com.sun.star.scanner.ScannerContext'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.scanner.ScannerContext'
    """Literal Constant ``com.sun.star.scanner.ScannerContext``"""

    def __init__(self, ScannerName: typing.Optional[str] = '', InternalData: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            ScannerName (str, optional): ScannerName value.
            InternalData (int, optional): InternalData value.
        """
        super().__init__()

        if isinstance(ScannerName, ScannerContext):
            oth: ScannerContext = ScannerName
            self.ScannerName = oth.ScannerName
            self.InternalData = oth.InternalData
            return

        kargs = {
            "ScannerName": ScannerName,
            "InternalData": InternalData,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._scanner_name = kwargs["ScannerName"]
        self._internal_data = kwargs["InternalData"]


    @property
    def ScannerName(self) -> str:
        """
        ScannerName contains a user readable identification.
        """
        return self._scanner_name

    @ScannerName.setter
    def ScannerName(self, value: str) -> None:
        self._scanner_name = value

    @property
    def InternalData(self) -> int:
        """
        InternalData contains service private data and must not be changed.
        """
        return self._internal_data

    @InternalData.setter
    def InternalData(self, value: int) -> None:
        self._internal_data = value


__all__ = ['ScannerContext']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ucb
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class Error(metaclass=UnoConstMeta, type_name="com.sun.star.ucb.Error", name_space="com.sun.star.ucb"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.ucb.Error``"""
        pass

    class ErrorEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.ucb.Error", name_space="com.sun.star.ucb"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.ucb.Error`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.ucb import Error as Error
    else:
        # keep document generators happy
        from ...lo.ucb.error import Error as Error

    class ErrorEnum(IntEnum):
        """
        Enum of Const Class Error

        These codes are used to indicate errors.
        
        .. deprecated::
        
            Class is deprecated.
        """
        NONE = Error.NONE
        LOGIN_FAILURE_RECEIVE = Error.LOGIN_FAILURE_RECEIVE
        LOGIN_FAILURE_NEWSSEND = Error.LOGIN_FAILURE_NEWSSEND
        LOGIN_FAILURE_MAILSEND = Error.LOGIN_FAILURE_MAILSEND
        CONNECT_FAILURE = Error.CONNECT_FAILURE
        UCB_OFFLINE = Error.UCB_OFFLINE
        UCB_SERVER_ERROR = Error.UCB_SERVER_ERROR
        STORAGE_READONLY = Error.STORAGE_READONLY
        STORAGE_KILLED = Error.STORAGE_KILLED
        WRONG_FILE_FORMAT = Error.WRONG_FILE_FORMAT
        UNSUPPORTED_URL = Error.UNSUPPORTED_URL
        CNTOUT_NO_FROM = Error.CNTOUT_NO_FROM
        TOO_MANY_GROUPS = Error.TOO_MANY_GROUPS
        DELETE_ABORTED = Error.DELETE_ABORTED
        QUERY_DELETE = Error.QUERY_DELETE
        NOTAVAILABLE = Error.NOTAVAILABLE
        VIM_LIBRARY_ERROR = Error.VIM_LIBRARY_ERROR
        FOLDER_INVALID = Error.FOLDER_INVALID
        FTP_RESOLVERERROR = Error.FTP_RESOLVERERROR
        FTP_NETWORKERROR = Error.FTP_NETWORKERROR
        FTP_NOTNECESSARYCMD = Error.FTP_NOTNECESSARYCMD
        FTP_SERVICEUNAVAILABLE = Error.FTP_SERVICEUNAVAILABLE
        FTP_DCONFAILURE = Error.FTP_DCONFAILURE
        FTP_TRANSFERABORTED = Error.FTP_TRANSFERABORTED
        NO_VIM_LIBRARY = Error.NO_VIM_LIBRARY
        VIM_LIBRARY_CORRUPTED = Error.VIM_LIBRARY_CORRUPTED
        CCMAIL_EXPORT_ERROR = Error.CCMAIL_EXPORT_ERROR
        NO_CCMAIL_EXPORT_FILE = Error.NO_CCMAIL_EXPORT_FILE
        ILLEGAL_CCMAIL_EXPORT_FILE = Error.ILLEGAL_CCMAIL_EXPORT_FILE
        MESSAGE_NOT_FOUND = Error.MESSAGE_NOT_FOUND
        BAD_CCMAIL_EXPORT_PASSWORD = Error.BAD_CCMAIL_EXPORT_PASSWORD
        CCMAIL_EXPORT_TOO_LONG = Error.CCMAIL_EXPORT_TOO_LONG
        FOLDER_EXISTS = Error.FOLDER_EXISTS
        FOLDER_NOT_EXISTS = Error.FOLDER_NOT_EXISTS
        NO_VIM_BBOARDLIST = Error.NO_VIM_BBOARDLIST
        ILLEGAL_MESSAGE_ID = Error.ILLEGAL_MESSAGE_ID
        SERVER_PORT_SYNTAX = Error.SERVER_PORT_SYNTAX
        SERVERNAME_SYNTAX = Error.SERVERNAME_SYNTAX
        USERNAME_SYNTAX = Error.USERNAME_SYNTAX
        IS_RESCHEDULED = Error.IS_RESCHEDULED
        VIM_NO_FAKE_MESSAGE_ID = Error.VIM_NO_FAKE_MESSAGE_ID
        FSYS_ROOT_DELETE = Error.FSYS_ROOT_DELETE
        FILE_EXISTS = Error.FILE_EXISTS
        FILE_NOT_EXISTS = Error.FILE_NOT_EXISTS
        FSYS_MISPLACED_CHAR = Error.FSYS_MISPLACED_CHAR
        FSYS_INVALID_CHAR = Error.FSYS_INVALID_CHAR
        FSYS_INVALID_DEVICE = Error.FSYS_INVALID_DEVICE
        FSYS_ACCESS_DENIED = Error.FSYS_ACCESS_DENIED
        FSYS_LOCK_VIOLATION = Error.FSYS_LOCK_VIOLATION
        FSYS_VOLUME_FULL = Error.FSYS_VOLUME_FULL
        FSYS_NOT_SUPPORTED = Error.FSYS_NOT_SUPPORTED
        FSYS_UNKNOWN = Error.FSYS_UNKNOWN
        FSYS_NOT_A_FILE = Error.FSYS_NOT_A_FILE
        FSYS_NOT_A_DIRECTORY = Error.FSYS_NOT_A_DIRECTORY
        FSYS_IS_WILDCARD = Error.FSYS_IS_WILDCARD
        RENAMED_WRONG_FILE_FORMAT = Error.RENAMED_WRONG_FILE_FORMAT
        FSYS_UPDATE_NEEDED = Error.FSYS_UPDATE_NEEDED
        FSYS_CANT_RESOLVE_CONFLICT = Error.FSYS_CANT_RESOLVE_CONFLICT
        FSYS_CANT_ITERATE = Error.FSYS_CANT_ITERATE
        ONE_NOT_SEARCHABLE = Error.ONE_NOT_SEARCHABLE
        MULTIPLE_NOT_SEARCHABLE = Error.MULTIPLE_NOT_SEARCHABLE
        FSYS_CACHE_INCONSISTENT = Error.FSYS_CACHE_INCONSISTENT
        FSYS_READONLY = Error.FSYS_READONLY
        FSYS_LOCK = Error.FSYS_LOCK
        FSYS_UNLOCK = Error.FSYS_UNLOCK
        FSYS_DELETE = Error.FSYS_DELETE
        FSYS_IS_MARKED = Error.FSYS_IS_MARKED
        FTP_GENERAL_FAILURE = Error.FTP_GENERAL_FAILURE
        DO_LOG = Error.DO_LOG
        HTTP_COOKIE_REQUEST = Error.HTTP_COOKIE_REQUEST
        FSYS_LOST_ROOT = Error.FSYS_LOST_ROOT
        FTP_PROXY = Error.FTP_PROXY
        SOURCE_SAME_AS_TARGET = Error.SOURCE_SAME_AS_TARGET
        CONFIRM_EMPTY_TRASH = Error.CONFIRM_EMPTY_TRASH
        FSYS_NO_TARGET = Error.FSYS_NO_TARGET
        FSYS_RECURSIVE = Error.FSYS_RECURSIVE
        FSYS_INSERT_MEDIUM = Error.FSYS_INSERT_MEDIUM
        NO_DOCINFO = Error.NO_DOCINFO
        CCMAIL_EXPORT_NOT_TERMINATING = Error.CCMAIL_EXPORT_NOT_TERMINATING
        EXTERNAL_COMMAND_FAILED = Error.EXTERNAL_COMMAND_FAILED
        RENAME_FAILED = Error.RENAME_FAILED
        NOT_HANDLED = Error.NOT_HANDLED
        COULD_NOT_INIT_COMPONENT = Error.COULD_NOT_INIT_COMPONENT
        TRANSFER_URL_NOT_SUPPORTED = Error.TRANSFER_URL_NOT_SUPPORTED
        EMPTY_SERVERNAME = Error.EMPTY_SERVERNAME
        EMPTY_USERNAME = Error.EMPTY_USERNAME
        BAD_INET = Error.BAD_INET
        IMAP_SERVER_MSG = Error.IMAP_SERVER_MSG
        IMAP_CONNECTION_CLOSED = Error.IMAP_CONNECTION_CLOSED
        IMAP_NOT_IMAP4 = Error.IMAP_NOT_IMAP4
        IMAP_BAD_SERVER = Error.IMAP_BAD_SERVER
        REORGANIZE_FILE_LOCKED = Error.REORGANIZE_FILE_LOCKED
        IMAP_BAD_TITLE = Error.IMAP_BAD_TITLE
        SERVER_CONNECT_FAILURE = Error.SERVER_CONNECT_FAILURE
        PASSWORD_SYNTAX = Error.PASSWORD_SYNTAX
        QUERY_DELETE_CACHE = Error.QUERY_DELETE_CACHE
        REORGANIZE_NO_DISKSPACE = Error.REORGANIZE_NO_DISKSPACE
        LOGIN_FAILURE_ACCOUNT = Error.LOGIN_FAILURE_ACCOUNT
        ACCOUNT_SYNTAX = Error.ACCOUNT_SYNTAX

__all__ = ['Error', 'ErrorEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.deployment
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..uno.exception import Exception as Exception_85530a09
from ..uno.x_interface import XInterface as XInterface_8f010a43
from .x_package import XPackage as XPackage_cb1f0c4d

class VersionException(Exception_85530a09):
    """
    Exception Class

    describes version clashes of a deployment unit.
    
    This exception is intended to be used with an com.sun.star.task.XInteractionHandler.
    
    **since**
    
        OOo 2.1

    See Also:
        `API VersionException <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1deployment_1_1VersionException.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.deployment'
    __ooo_full_ns__: str = 'com.sun.star.deployment.VersionException'
    __ooo_type_name__: str = 'exception'
    __pyunointerface__: str = 'com.sun.star.deployment.VersionException'
    __pyunostruct__: str = 'com.sun.star.deployment.VersionException'

    typeName: str = 'com.sun.star.deployment.VersionException'
    """Literal Constant ``com.sun.star.deployment.VersionException``"""

    def __init__(self, Message: typing.Optional[str] = '', Context: typing.Optional[XInterface_8f010a43] = None, NewVersion: typing.Optional[str] = '', NewDisplayName: typing.Optional[str] = '', Deployed: typing.Optional[XPackage_cb1f0c4d] = None) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            NewVersion (str, optional): NewVersion value.
            NewDisplayName (str, optional): NewDisplayName value.
            Deployed (XPackage, optional): Deployed value.
        """
        kargs = {
            "Message": Message,
            "Context": Context,
            "NewVersion": NewVersion,
            "NewDisplayName": NewDisplayName,
            "Deployed": Deployed,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._new_version = kwargs["NewVersion"]
        self._new_display_name = kwargs["NewDisplayName"]
        self._deployed = kwargs["Deployed"]
        inst_keys = ('NewVersion', 'NewDisplayName', 'Deployed')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)

    @property
    def NewVersion(self) -> str:
        """
        the version of the extension which is being installed.
        """
        return self._new_version
    
    @NewVersion.setter
    def NewVersion(self, value: str) -> None:
        self._new_version = value

    @property
    def NewDisplayName(self) -> str:
        """
        the display name of the extension which is being installed.
        """
        return self._new_display_name
    
    @NewDisplayName.setter
    def NewDisplayName(self, value: str) -> None:
        self._new_display_name = value

    @property
    def Deployed(self) -> XPackage_cb1f0c4d:
        """
        represents the already installed version of the deployment unit.
        
        Must not be NULL.
        """
        return self._deployed
    
    @Deployed.setter
    def Deployed(self, value: XPackage_cb1f0c4d) -> None:
        self._deployed = value


__all__ = ['VersionException']




# coding: utf-8
try:
    import uno
except ImportError:
    pass
import sys
import os
from typing import TYPE_CHECKING

UNO_ENVIRONMENT = False
if not TYPE_CHECKING:
    UNO_ENVIRONMENT = (
        "uno" in sys.modules and hasattr(sys.modules["uno"], "getComponentContext")
    ) and callable(sys.modules["uno"].getComponentContext)

UNO_RUNTIME = (
    False
    if (
        UNO_ENVIRONMENT is False
        or os.environ.get("ooouno_ignore_runtime", None) == "True"
    )
    else True
)

UNO_NONE = object()

__all__ = ["UNO_ENVIRONMENT", "UNO_RUNTIME", "UNO_NONE"]



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.scanner
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class ScanError(metaclass=UnoEnumMeta, type_name="com.sun.star.scanner.ScanError", name_space="com.sun.star.scanner"):
        """Dynamically created class that represents ``com.sun.star.scanner.ScanError`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.scanner.ScanError import InvalidContext as SCAN_ERROR_InvalidContext
        from com.sun.star.scanner.ScanError import ScanCanceled as SCAN_ERROR_ScanCanceled
        from com.sun.star.scanner.ScanError import ScanErrorNone as SCAN_ERROR_ScanErrorNone
        from com.sun.star.scanner.ScanError import ScanFailed as SCAN_ERROR_ScanFailed
        from com.sun.star.scanner.ScanError import ScanInProgress as SCAN_ERROR_ScanInProgress
        from com.sun.star.scanner.ScanError import ScannerNotAvailable as SCAN_ERROR_ScannerNotAvailable

        class ScanError(uno.Enum):
            """
            Enum Class


            See Also:
                `API ScanError <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1scanner.html#abd1619ea132004db8599d9529755e9ab>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.scanner.ScanError', value)

            __ooo_ns__: str = 'com.sun.star.scanner'
            __ooo_full_ns__: str = 'com.sun.star.scanner.ScanError'
            __ooo_type_name__: str = 'enum'

            InvalidContext = SCAN_ERROR_InvalidContext
            """
            InvalidContext: a device was requested that does not exist.
            """
            ScanCanceled = SCAN_ERROR_ScanCanceled
            """
            ScanCanceled: the scan was canceled by the user.
            """
            ScanErrorNone = SCAN_ERROR_ScanErrorNone
            """
            ScanErrorNone: no error occurred.
            """
            ScanFailed = SCAN_ERROR_ScanFailed
            """
            ScanFailed: an error occurred during scanning.
            """
            ScanInProgress = SCAN_ERROR_ScanInProgress
            """
            ScanInProgress: a scan is already in progress on this device that has to end before a new one can be started.
            """
            ScannerNotAvailable = SCAN_ERROR_ScannerNotAvailable
            """
            ScannerNotAvailable: the requested device could not be opened.
            """
    else:
        # keep document generators happy
        from ...lo.scanner.scan_error import ScanError as ScanError


__all__ = ['ScanError']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.xml.xpath
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class Libxml2ExtensionHandle(object):
    """
    Struct Class


    See Also:
        `API Libxml2ExtensionHandle <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1xml_1_1xpath_1_1Libxml2ExtensionHandle.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.xpath'
    __ooo_full_ns__: str = 'com.sun.star.xml.xpath.Libxml2ExtensionHandle'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.xml.xpath.Libxml2ExtensionHandle'
    """Literal Constant ``com.sun.star.xml.xpath.Libxml2ExtensionHandle``"""

    def __init__(self, functionLookupFunction: typing.Optional[int] = 0, functionData: typing.Optional[int] = 0, variableLookupFunction: typing.Optional[int] = 0, variableData: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            functionLookupFunction (int, optional): functionLookupFunction value.
            functionData (int, optional): functionData value.
            variableLookupFunction (int, optional): variableLookupFunction value.
            variableData (int, optional): variableData value.
        """
        super().__init__()

        if isinstance(functionLookupFunction, Libxml2ExtensionHandle):
            oth: Libxml2ExtensionHandle = functionLookupFunction
            self.functionLookupFunction = oth.functionLookupFunction
            self.functionData = oth.functionData
            self.variableLookupFunction = oth.variableLookupFunction
            self.variableData = oth.variableData
            return

        kargs = {
            "functionLookupFunction": functionLookupFunction,
            "functionData": functionData,
            "variableLookupFunction": variableLookupFunction,
            "variableData": variableData,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._function_lookup_function = kwargs["functionLookupFunction"]
        self._function_data = kwargs["functionData"]
        self._variable_lookup_function = kwargs["variableLookupFunction"]
        self._variable_data = kwargs["variableData"]


    @property
    def functionLookupFunction(self) -> int:
        return self._function_lookup_function

    @functionLookupFunction.setter
    def functionLookupFunction(self, value: int) -> None:
        self._function_lookup_function = value

    @property
    def functionData(self) -> int:
        return self._function_data

    @functionData.setter
    def functionData(self, value: int) -> None:
        self._function_data = value

    @property
    def variableLookupFunction(self) -> int:
        return self._variable_lookup_function

    @variableLookupFunction.setter
    def variableLookupFunction(self, value: int) -> None:
        self._variable_lookup_function = value

    @property
    def variableData(self) -> int:
        return self._variable_data

    @variableData.setter
    def variableData(self, value: int) -> None:
        self._variable_data = value


__all__ = ['Libxml2ExtensionHandle']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui
from __future__ import annotations
from ..container.x_container import XContainer as XContainer_d6fb0cc6
from ..container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
from ..container.x_index_container import XIndexContainer as XIndexContainer_1c040ebe
from ..lang.x_multi_service_factory import XMultiServiceFactory as XMultiServiceFactory_191e0eb6

class ActionTriggerContainer(XContainer_d6fb0cc6, XEnumerationAccess_4bac0ffc, XIndexContainer_1c040ebe, XMultiServiceFactory_191e0eb6):
    """
    Service Class

    describes a container of user actions.
    
    No assumption is made about any graphical representation: You could have a menu or a toolbox working with the same container describing their entries.
    
    Possible elements of the ActionTriggerContainer are

    See Also:
        `API ActionTriggerContainer <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1ui_1_1ActionTriggerContainer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui'
    __ooo_full_ns__: str = 'com.sun.star.ui.ActionTriggerContainer'
    __ooo_type_name__: str = 'service'


__all__ = ['ActionTriggerContainer']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .folder_list_command import FolderListCommand as FolderListCommand_e0140cf9
from .folder_list_entry import FolderListEntry as FolderListEntry_c6c30c4c


class FolderList(object):
    """
    Struct Class

    A list of folders.

    See Also:
        `API FolderList <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1FolderList.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.FolderList'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.ucb.FolderList'
    """Literal Constant ``com.sun.star.ucb.FolderList``"""

    def __init__(self, List: typing.Optional[typing.Tuple[FolderListEntry_c6c30c4c, ...]] = (), Command: typing.Optional[FolderListCommand_e0140cf9] = FolderListCommand_e0140cf9.GET) -> None:
        """
        Constructor

        Arguments:
            List (typing.Tuple[FolderListEntry, ...], optional): List value.
            Command (FolderListCommand, optional): Command value.
        """
        super().__init__()

        if isinstance(List, FolderList):
            oth: FolderList = List
            self.List = oth.List
            self.Command = oth.Command
            return

        kargs = {
            "List": List,
            "Command": Command,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._list = kwargs["List"]
        self._command = kwargs["Command"]


    @property
    def List(self) -> typing.Tuple[FolderListEntry_c6c30c4c, ...]:
        """
        The list of folders (only used in conjunction with FolderListCommand.SET).
        """
        return self._list

    @List.setter
    def List(self, value: typing.Tuple[FolderListEntry_c6c30c4c, ...]) -> None:
        self._list = value

    @property
    def Command(self) -> FolderListCommand_e0140cf9:
        """
        The command to process on this list of folders.
        """
        return self._command

    @Command.setter
    def Command(self, value: FolderListCommand_e0140cf9) -> None:
        self._command = value


__all__ = ['FolderList']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class FilterOperator(metaclass=UnoEnumMeta, type_name="com.sun.star.sheet.FilterOperator", name_space="com.sun.star.sheet"):
        """Dynamically created class that represents ``com.sun.star.sheet.FilterOperator`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.sheet.FilterOperator import BOTTOM_PERCENT as FILTER_OPERATOR_BOTTOM_PERCENT
        from com.sun.star.sheet.FilterOperator import BOTTOM_VALUES as FILTER_OPERATOR_BOTTOM_VALUES
        from com.sun.star.sheet.FilterOperator import EMPTY as FILTER_OPERATOR_EMPTY
        from com.sun.star.sheet.FilterOperator import EQUAL as FILTER_OPERATOR_EQUAL
        from com.sun.star.sheet.FilterOperator import GREATER as FILTER_OPERATOR_GREATER
        from com.sun.star.sheet.FilterOperator import GREATER_EQUAL as FILTER_OPERATOR_GREATER_EQUAL
        from com.sun.star.sheet.FilterOperator import LESS as FILTER_OPERATOR_LESS
        from com.sun.star.sheet.FilterOperator import LESS_EQUAL as FILTER_OPERATOR_LESS_EQUAL
        from com.sun.star.sheet.FilterOperator import NOT_EMPTY as FILTER_OPERATOR_NOT_EMPTY
        from com.sun.star.sheet.FilterOperator import NOT_EQUAL as FILTER_OPERATOR_NOT_EQUAL
        from com.sun.star.sheet.FilterOperator import TOP_PERCENT as FILTER_OPERATOR_TOP_PERCENT
        from com.sun.star.sheet.FilterOperator import TOP_VALUES as FILTER_OPERATOR_TOP_VALUES

        class FilterOperator(uno.Enum):
            """
            Enum Class


            See Also:
                `API FilterOperator <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet.html#af9e5fd8fd26fc252748d97ebd68ea6b1>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.sheet.FilterOperator', value)

            __ooo_ns__: str = 'com.sun.star.sheet'
            __ooo_full_ns__: str = 'com.sun.star.sheet.FilterOperator'
            __ooo_type_name__: str = 'enum'

            BOTTOM_PERCENT = FILTER_OPERATOR_BOTTOM_PERCENT
            """
            selects a specified percentage of entries with the lowest values.
            """
            BOTTOM_VALUES = FILTER_OPERATOR_BOTTOM_VALUES
            """
            selects a specified number of entries with the lowest values.
            """
            EMPTY = FILTER_OPERATOR_EMPTY
            """
            selects empty entries.
            """
            EQUAL = FILTER_OPERATOR_EQUAL
            """
            value has to be equal to the specified value.

            The cell value is equal to the specified value.
            """
            GREATER = FILTER_OPERATOR_GREATER
            """
            the value has to be greater than the specified value.

            value has to be greater than the specified value.
            """
            GREATER_EQUAL = FILTER_OPERATOR_GREATER_EQUAL
            """
            the value has to be greater than or equal to the specified value.

            The cell value is greater or equal to the specified value.

            value has to be greater than or equal to the specified value.
            """
            LESS = FILTER_OPERATOR_LESS
            """
            the value has to be less than the specified value.

            value has to be less than the specified value.
            """
            LESS_EQUAL = FILTER_OPERATOR_LESS_EQUAL
            """
            the value has to be less than or equal to the specified value.

            The cell value is less or equal to the specified value.

            value has to be less than or equal to the specified value.
            """
            NOT_EMPTY = FILTER_OPERATOR_NOT_EMPTY
            """
            selects non-empty entries.
            """
            NOT_EQUAL = FILTER_OPERATOR_NOT_EQUAL
            """
            the value must not be equal to the specified value.

            value must not be equal to the specified value.
            """
            TOP_PERCENT = FILTER_OPERATOR_TOP_PERCENT
            """
            selects a specified percentage of entries with the greatest values.
            """
            TOP_VALUES = FILTER_OPERATOR_TOP_VALUES
            """
            selects a specified number of entries with the greatest values.
            """
    else:
        # keep document generators happy
        from ...lo.sheet.filter_operator import FilterOperator as FilterOperator


__all__ = ['FilterOperator']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.script
from __future__ import annotations
import typing
from abc import abstractmethod
from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6
if typing.TYPE_CHECKING:
    from ..container.x_name_container import XNameContainer as XNameContainer_cb90e47

class XLibraryContainer(XNameAccess_e2ab0cf6):
    """
    Provides access to a library system.

    See Also:
        `API XLibraryContainer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1script_1_1XLibraryContainer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.script'
    __ooo_full_ns__: str = 'com.sun.star.script.XLibraryContainer'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.script.XLibraryContainer'

    @abstractmethod
    def createLibrary(self, Name: str) -> XNameContainer_cb90e47:
        """
        Creates a new library.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.ElementExistException: ``ElementExistException``
        """
        ...
    @abstractmethod
    def createLibraryLink(self, Name: str, StorageURL: str, ReadOnly: bool) -> XNameAccess_e2ab0cf6:
        """
        Creates a link to an \"external\" library that then can be accessed using this library manager.
        
        The format of the StorageURL is a matter of the implementation. If the read only flag is set, the linked library cannot be modified. In this case, the returned interface really is only an XNameAccess. If ReadOnly is false (and the referenced storage allows write access) the returned interface also can be a com.sun.star.container.XNameContainer.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.ElementExistException: ``ElementExistException``
        """
        ...
    @abstractmethod
    def isLibraryLoaded(self, Name: str) -> bool:
        """
        returns true if the accessed library is already loaded from the storage, otherwise false.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...
    @abstractmethod
    def loadLibrary(self, Name: str) -> None:
        """
        Causes the accessed library to be loaded from its storage if it hasn't already been loaded.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def removeLibrary(self, Name: str) -> None:
        """
        removes the library item with the specified name.
        
        If the accessed library item is a link only the link is removed, not the target library.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...

__all__ = ['XLibraryContainer']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.frame.status
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class ItemStatus(object):
    """
    Struct Class

    describes a state of a property.
    
    **since**
    
        OOo 2.0

    See Also:
        `API ItemStatus <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1frame_1_1status_1_1ItemStatus.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame.status'
    __ooo_full_ns__: str = 'com.sun.star.frame.status.ItemStatus'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.frame.status.ItemStatus'
    """Literal Constant ``com.sun.star.frame.status.ItemStatus``"""

    def __init__(self, State: typing.Optional[int] = 0, aStateData: typing.Optional[object] = None) -> None:
        """
        Constructor

        Arguments:
            State (int, optional): State value.
            aStateData (object, optional): aStateData value.
        """
        super().__init__()

        if isinstance(State, ItemStatus):
            oth: ItemStatus = State
            self.State = oth.State
            self.aStateData = oth.aStateData
            return

        kargs = {
            "State": State,
            "aStateData": aStateData,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._state = kwargs["State"]
        self._a_state_data = kwargs["aStateData"]


    @property
    def State(self) -> int:
        """
        numerical value which describes the current state of an item.
        """
        return self._state

    @State.setter
    def State(self, value: int) -> None:
        self._state = value

    @property
    def aStateData(self) -> object:
        """
        optional data which can be used by an implementation to send additional information.
        
        The content is dependent on the specific implementation.
        """
        return self._a_state_data

    @aStateData.setter
    def aStateData(self, value: object) -> None:
        self._a_state_data = value


__all__ = ['ItemStatus']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .filter_connection import FilterConnection as FilterConnection_f01f0d97
from .filter_field_value import FilterFieldValue as FilterFieldValue_ef2a0d68


class TableFilterField3(object):
    """
    Struct Class

    
    **since**
    
        LibreOffice 3.5

    See Also:
        `API TableFilterField3 <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sheet_1_1TableFilterField3.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.TableFilterField3'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.sheet.TableFilterField3'
    """Literal Constant ``com.sun.star.sheet.TableFilterField3``"""

    def __init__(self, Values: typing.Optional[typing.Tuple[FilterFieldValue_ef2a0d68, ...]] = (), Connection: typing.Optional[FilterConnection_f01f0d97] = FilterConnection_f01f0d97.AND, Field: typing.Optional[int] = 0, Operator: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Values (typing.Tuple[FilterFieldValue, ...], optional): Values value.
            Connection (FilterConnection, optional): Connection value.
            Field (int, optional): Field value.
            Operator (int, optional): Operator value.
        """
        super().__init__()

        if isinstance(Values, TableFilterField3):
            oth: TableFilterField3 = Values
            self.Values = oth.Values
            self.Connection = oth.Connection
            self.Field = oth.Field
            self.Operator = oth.Operator
            return

        kargs = {
            "Values": Values,
            "Connection": Connection,
            "Field": Field,
            "Operator": Operator,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._values = kwargs["Values"]
        self._connection = kwargs["Connection"]
        self._field = kwargs["Field"]
        self._operator = kwargs["Operator"]


    @property
    def Values(self) -> typing.Tuple[FilterFieldValue_ef2a0d68, ...]:
        """
        specifies values to match against.
        
        Each filter field may have one or more values.
        """
        return self._values

    @Values.setter
    def Values(self, value: typing.Tuple[FilterFieldValue_ef2a0d68, ...]) -> None:
        self._values = value

    @property
    def Connection(self) -> FilterConnection_f01f0d97:
        """
        specifies how the condition is connected to the previous condition.
        """
        return self._connection

    @Connection.setter
    def Connection(self, value: FilterConnection_f01f0d97) -> None:
        self._connection = value

    @property
    def Field(self) -> int:
        """
        specifies which field (column) is used for the condition.
        """
        return self._field

    @Field.setter
    def Field(self, value: int) -> None:
        self._field = value

    @property
    def Operator(self) -> int:
        """
        specifies the type of the condition as defined in FilterOperator2.
        """
        return self._operator

    @Operator.setter
    def Operator(self, value: int) -> None:
        self._operator = value


__all__ = ['TableFilterField3']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.crypto
from __future__ import annotations
import typing
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_security_environment import XSecurityEnvironment as XSecurityEnvironment_7ead116d
    from .xxml_security_context import XXMLSecurityContext as XXMLSecurityContext_681010ae
    from .xxml_signature_template import XXMLSignatureTemplate as XXMLSignatureTemplate_89fe115f

class XXMLSignature(XInterface_8f010a43):
    """
    Interface of XML signature.
    
    This interface represents a XML signer or verifier.
    
    The signer or verifier concrete a key by retrieve signature context and signature template.
    
    In some cases, the signer or verifier can determine and locate the contents to be signed from the signature template by dereference the URI.
    
    In some cases, the contents to be signed need to be clearly pointed out by the signature template.

    See Also:
        `API XXMLSignature <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1XXMLSignature.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.crypto'
    __ooo_full_ns__: str = 'com.sun.star.xml.crypto.XXMLSignature'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.crypto.XXMLSignature'

    @abstractmethod
    def generate(self, aTemplate: XXMLSignatureTemplate_89fe115f, aEnvironment: XSecurityEnvironment_7ead116d) -> XXMLSignatureTemplate_89fe115f:
        """
        Perform signature in the environment of signature template and context.

        Raises:
            : ````
            com.sun.star.uno.SecurityException: ``SecurityException``
        """
        ...
    @abstractmethod
    def validate(self, aTemplate: XXMLSignatureTemplate_89fe115f, aContext: XXMLSecurityContext_681010ae) -> XXMLSignatureTemplate_89fe115f:
        """
        Perform validation in the environment of signature template and context.

        Raises:
            : ````
            com.sun.star.uno.SecurityException: ``SecurityException``
        """
        ...

__all__ = ['XXMLSignature']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb.tools
from __future__ import annotations
from abc import abstractmethod, ABC

class XObjectNames(ABC):
    """
    encapsulates functionality which you might find useful when writing a database application which deals with query and table names.
    
    The most important task fulfilled by this instance is that it hides different naming restrictions from you, which are caused by server-side or client side specialties.
    
    For instance, it can validate names against the characters allowed in the object names of a connection. Also, it relieves you from caring whether a database supports queries in a SELECT statement's FROM part (known as \"queries in queries\"). In such databases, query and table names share a common namespace, thus they must be unique. Using this interface, you can easily ensure this uniqueness.
    
    All of the functionality present in this interface depends on a connection, thus it entry point for obtaining it is a com.sun.star.sdb.Connection service.
    
    The component itself does not have life-time control mechanisms, i.e. you cannot explicitly dispose it (com.sun.star.lang.XComponent.dispose()), and you cannot be notified when it dies.However, if your try to access any of its methods or attributes, after the connection which was used to create it was closed, a com.sun.star.lang.DisposedException will be thrown.
    
    **since**
    
        OOo 2.0.4

    See Also:
        `API XObjectNames <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdb_1_1tools_1_1XObjectNames.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb.tools'
    __ooo_full_ns__: str = 'com.sun.star.sdb.tools.XObjectNames'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdb.tools.XObjectNames'

    @abstractmethod
    def checkNameForCreate(self, CommandType: int, Name: str) -> None:
        """
        checks whether a given name is allowed for a to-be-created table or query in the database.
        
        This method basically does the same checks as isNameUsed() and isNameValid(). In case the given name is not allowed, it throws an exception. This error can be presented to the user, to give it a common experience in all cases where he's required to enter an object name.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def convertToSQLName(self, Name: str) -> str:
        """
        converts the given object name to a name which is valid in the database.
        
        The conversion takes place by converting every character which is neither allowed by the SQL-92 standard, nor part of the special characters supported by the database, with an underscore character (_).
        """
        ...
    @abstractmethod
    def isNameUsed(self, CommandType: int, Name: str) -> bool:
        """
        checks whether a given name is used as table respectively query name in the database.
        
        If in the database, tables and queries share a common namespace, this will be respected by this function.
        
        As before, the information you obtain by calling this method might be obsolete in the very moment you evaluate this, in case another process or thread interferes. However, it's usually sufficiently up-to-date for purpose of using it in a database application driven by user interactions.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def isNameValid(self, CommandType: int, Name: str) -> bool:
        """
        checks whether a given name is valid as table or query name
        
        For tables, the name must consist of characters allowed by the SQL-92 standard, plus characters allowed by the connection as extra name characters.
        
        For queries, names are nearly arbitrary, except that usual quoting characters must not be part of the name.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def suggestName(self, CommandType: int, BaseName: str) -> str:
        """
        suggests a (unique) table or query name
        
        If in the database, tables and queries share a common namespace, this will be respected by this function.
        
        Note that in an multi-threaded environment, the name you obtain here is not absolutely guaranteed to be unique. It is unique at the very moment the function returns to you. But already when you evaluate the returned value, it might not be unique anymore, if another process or thread created a query or table with this name.
        
        This implies that you cannot rely on the name's uniqueness, but you can use it as first guess to present to the user. In most cases, it will still be sufficient when you are actually creating the table respectively query.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
        ...

__all__ = ['XObjectNames']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
import typing
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..document.office_document import OfficeDocument as OfficeDocument_fecd0df2
from ..lang.x_multi_service_factory import XMultiServiceFactory as XMultiServiceFactory_191e0eb6
from ..style.x_style_families_supplier import XStyleFamiliesSupplier as XStyleFamiliesSupplier_4c5a1020
from .x_bookmarks_supplier import XBookmarksSupplier as XBookmarksSupplier_ffa50e22
from .x_chapter_numbering_supplier import XChapterNumberingSupplier as XChapterNumberingSupplier_6bb310e7
from .x_document_indexes_supplier import XDocumentIndexesSupplier as XDocumentIndexesSupplier_5b991088
from .x_endnotes_supplier import XEndnotesSupplier as XEndnotesSupplier_f19c0db9
from .x_footnotes_supplier import XFootnotesSupplier as XFootnotesSupplier_1050e3a
from .x_page_printable import XPagePrintable as XPagePrintable_c8670c43
from .x_reference_marks_supplier import XReferenceMarksSupplier as XReferenceMarksSupplier_49d81006
from .x_text_document import XTextDocument as XTextDocument_bd4b0c09
from .x_text_embedded_objects_supplier import XTextEmbeddedObjectsSupplier as XTextEmbeddedObjectsSupplier_9dd211f2
from .x_text_fields_supplier import XTextFieldsSupplier as XTextFieldsSupplier_d5d0e75
from .x_text_frames_supplier import XTextFramesSupplier as XTextFramesSupplier_db70e7c
from .x_text_graphic_objects_supplier import XTextGraphicObjectsSupplier as XTextGraphicObjectsSupplier_8df111a6
from .x_text_sections_supplier import XTextSectionsSupplier as XTextSectionsSupplier_2ce60f66
from .x_text_tables_supplier import XTextTablesSupplier as XTextTablesSupplier_d9f0e79
from ..tiledrendering.x_tiled_renderable import XTiledRenderable as XTiledRenderable_7efc1116
from ..util.x_number_formats_supplier import XNumberFormatsSupplier as XNumberFormatsSupplier_3afb0fb7
from ..util.x_refreshable import XRefreshable as XRefreshable_b0d60b81
from ..util.x_replaceable import XReplaceable as XReplaceable_b0750b6e
from ..util.x_searchable import XSearchable as XSearchable_a4e80b08
if typing.TYPE_CHECKING:
    from ..lang.locale import Locale as Locale_70d308fa

class GenericTextDocument(OfficeDocument_fecd0df2, XPropertySet_bc180bfa, XMultiServiceFactory_191e0eb6, XStyleFamiliesSupplier_4c5a1020, XBookmarksSupplier_ffa50e22, XChapterNumberingSupplier_6bb310e7, XDocumentIndexesSupplier_5b991088, XEndnotesSupplier_f19c0db9, XFootnotesSupplier_1050e3a, XPagePrintable_c8670c43, XReferenceMarksSupplier_49d81006, XTextDocument_bd4b0c09, XTextEmbeddedObjectsSupplier_9dd211f2, XTextFieldsSupplier_d5d0e75, XTextFramesSupplier_db70e7c, XTextGraphicObjectsSupplier_8df111a6, XTextSectionsSupplier_2ce60f66, XTextTablesSupplier_d9f0e79, XTiledRenderable_7efc1116, XNumberFormatsSupplier_3afb0fb7, XRefreshable_b0d60b81, XReplaceable_b0750b6e, XSearchable_a4e80b08):
    """
    Service Class

    A text document is a model component which contains text structured by paragraphs.
    
    Each paragraph and each portion of text can be fitted with some attributes (technically properties).
    
    It's declared as generic text document, because its function is needed by different derived services (TextDocument/WebDocument/GlobalDocument).
    
    In addition, all text objects can be searched.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API GenericTextDocument <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1GenericTextDocument.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.GenericTextDocument'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def CharLocale(self) -> Locale_70d308fa:
        """
        contains the identifier of the default locale of the document.
        """
        ...

    @abstractproperty
    def CharacterCount(self) -> int:
        """
        contains the count of all characters in the document.
        """
        ...

    @abstractproperty
    def IndexAutoMarkFileURL(self) -> str:
        """
        specifies the concordance file taken into account when creating an index.
        
        When no concordance file should be used the string is empty. Used for text documents only.
        
        **since**
        
            OOo 1.1.2
        """
        ...

    @abstractproperty
    def ParagraphCount(self) -> int:
        """
        contains the count of all paragraphs in the document.
        """
        ...

    @abstractproperty
    def RecordChanges(self) -> bool:
        """
        specifies if change recording is active.
        
        **since**
        
            OOo 1.1.2
        """
        ...

    @abstractproperty
    def TwoDigitYear(self) -> int:
        """
        specifies the first 4 digit year to be used when years are given in 2 digits.
        
        Example: if set to 1930 Oct-12-29 will be interpreted as Oct-12-2029 Oct-12-30 will be interpreted as Oct-12-1930 Oct-12-02 will be interpreted as Oct-12-2002
        
        **since**
        
            OOo 1.1.2
        """
        ...

    @abstractproperty
    def WordCount(self) -> int:
        """
        contains the count of all words in the document.
        """
        ...

    @abstractproperty
    def WordSeparator(self) -> str:
        """
        contains a string that consists of characters that mark the separation of words in counting the words in a document.
        
        I.e. slash and backslash. Whitespace (tab stop, space, paragraph break, line break) always separate words.
        """
        ...


__all__ = ['GenericTextDocument']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.table
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class CellAddress(object):
    """
    Struct Class

    contains a cell address within a spreadsheet document.

    See Also:
        `API CellAddress <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1table_1_1CellAddress.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.table'
    __ooo_full_ns__: str = 'com.sun.star.table.CellAddress'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.table.CellAddress'
    """Literal Constant ``com.sun.star.table.CellAddress``"""

    def __init__(self, Sheet: typing.Optional[int] = 0, Column: typing.Optional[int] = 0, Row: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Sheet (int, optional): Sheet value.
            Column (int, optional): Column value.
            Row (int, optional): Row value.
        """
        super().__init__()

        if isinstance(Sheet, CellAddress):
            oth: CellAddress = Sheet
            self.Sheet = oth.Sheet
            self.Column = oth.Column
            self.Row = oth.Row
            return

        kargs = {
            "Sheet": Sheet,
            "Column": Column,
            "Row": Row,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._sheet = kwargs["Sheet"]
        self._column = kwargs["Column"]
        self._row = kwargs["Row"]


    @property
    def Sheet(self) -> int:
        """
        is the index of the sheet that contains the cell.
        """
        return self._sheet

    @Sheet.setter
    def Sheet(self, value: int) -> None:
        self._sheet = value

    @property
    def Column(self) -> int:
        """
        is the index of the column where the cell is located.
        """
        return self._column

    @Column.setter
    def Column(self, value: int) -> None:
        self._column = value

    @property
    def Row(self) -> int:
        """
        is the index of the row where the cell is located.
        """
        return self._row

    @Row.setter
    def Row(self, value: int) -> None:
        self._row = value


__all__ = ['CellAddress']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.animations
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class AnimationNodeType(metaclass=UnoConstMeta, type_name="com.sun.star.animations.AnimationNodeType", name_space="com.sun.star.animations"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.animations.AnimationNodeType``"""
        pass

    class AnimationNodeTypeEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.animations.AnimationNodeType", name_space="com.sun.star.animations"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.animations.AnimationNodeType`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.animations import AnimationNodeType as AnimationNodeType
    else:
        # keep document generators happy
        from ...lo.animations.animation_node_type import AnimationNodeType as AnimationNodeType

    class AnimationNodeTypeEnum(IntEnum):
        """
        Enum of Const Class AnimationNodeType

        This constants defines a type for an animation node.
        
        It can be used to quickly identify semantic blocks inside an animation hierarchy.
        
        **since**
        
            LibreOffice 7.1
        """
        CUSTOM = AnimationNodeType.CUSTOM
        """
        Defines a custom time node.
        """
        PAR = AnimationNodeType.PAR
        """
        Defines a parallel time container.
        """
        SEQ = AnimationNodeType.SEQ
        """
        Defines a sequence time container.
        """
        ITERATE = AnimationNodeType.ITERATE
        """
        Defines an iterate time container.
        """
        ANIMATE = AnimationNodeType.ANIMATE
        """
        Defines a generic attribute animation.
        """
        SET = AnimationNodeType.SET
        """
        Defines a simple mean of just setting the value of an attribute for a specified duration.
        """
        ANIMATEMOTION = AnimationNodeType.ANIMATEMOTION
        """
        Defines a move animation along a path.
        """
        ANIMATECOLOR = AnimationNodeType.ANIMATECOLOR
        """
        Defines an animation of a color attribute.
        """
        ANIMATETRANSFORM = AnimationNodeType.ANIMATETRANSFORM
        """
        Defines an animation of a transformation attribute.
        """
        TRANSITIONFILTER = AnimationNodeType.TRANSITIONFILTER
        """
        Defines an animation of a filter behavior.
        """
        AUDIO = AnimationNodeType.AUDIO
        """
        Defines an audio effect.
        """
        COMMAND = AnimationNodeType.COMMAND
        """
        Defines a command effect.
        """
        ANIMATEPHYSICS = AnimationNodeType.ANIMATEPHYSICS
        """
        Defines a physics animation.
        
        **since**
        
            LibreOffice 7.1
        """

__all__ = ['AnimationNodeType', 'AnimationNodeTypeEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.awt
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from ..lang.event_object import EventObject as EventObject_a3d70b03
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing


class ItemEvent(EventObject_a3d70b03):
    """
    Struct Class

    specifies an event occurred to an item of a menu, a list box etc.

    See Also:
        `API ItemEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1awt_1_1ItemEvent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.ItemEvent'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.awt.ItemEvent'
    """Literal Constant ``com.sun.star.awt.ItemEvent``"""

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = None, Selected: typing.Optional[int] = 0, Highlighted: typing.Optional[int] = 0, ItemId: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            Selected (int, optional): Selected value.
            Highlighted (int, optional): Highlighted value.
            ItemId (int, optional): ItemId value.
        """

        if isinstance(Source, ItemEvent):
            oth: ItemEvent = Source
            self.Source = oth.Source
            self.Selected = oth.Selected
            self.Highlighted = oth.Highlighted
            self.ItemId = oth.ItemId
            return

        kargs = {
            "Source": Source,
            "Selected": Selected,
            "Highlighted": Highlighted,
            "ItemId": ItemId,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._selected = kwargs["Selected"]
        self._highlighted = kwargs["Highlighted"]
        self._item_id = kwargs["ItemId"]
        inst_keys = ('Selected', 'Highlighted', 'ItemId')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def Selected(self) -> int:
        """
        specifies which item is newly selected.
        """
        return self._selected

    @Selected.setter
    def Selected(self, value: int) -> None:
        self._selected = value

    @property
    def Highlighted(self) -> int:
        """
        specifies which item is newly highlighted.
        """
        return self._highlighted

    @Highlighted.setter
    def Highlighted(self, value: int) -> None:
        self._highlighted = value

    @property
    def ItemId(self) -> int:
        """
        specifies the id of the item.
        """
        return self._item_id

    @ItemId.setter
    def ItemId(self, value: int) -> None:
        self._item_id = value


__all__ = ['ItemEvent']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_tab_listener import XTabListener as XTabListener_a36e0b09
    from ..beans.named_value import NamedValue as NamedValue_a37a0af3

class XSimpleTabController(XInterface_8f010a43):
    """
    specifies the basic operations for a tab controller, but does not require XControl as type of tabs.

    See Also:
        `API XSimpleTabController <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XSimpleTabController.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XSimpleTabController'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XSimpleTabController'

    @abstractmethod
    def activateTab(self, ID: int) -> None:
        """
        activate the specified tab.
        
        The new tab will be activated and all listener will get an event describing this. Of course there will be an event too, which notifies listener about the deactivation of the last active tab.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def addTabListener(self, Listener: XTabListener_a36e0b09) -> None:
        """
        register listener for inserting/removing tabs and changing their properties.
        """
        ...
    @abstractmethod
    def getActiveTabID(self) -> int:
        """
        return the unique ID of the current active tab.
        """
        ...
    @abstractmethod
    def getTabProps(self, ID: int) -> typing.Tuple[NamedValue_a37a0af3, ...]:
        """
        retrieve the set of properties for the specified tab.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def insertTab(self) -> int:
        """
        create a new tab and return a unique ID, which can be used further to address this tab by using other methods of this interface.
        """
        ...
    @abstractmethod
    def removeTab(self, ID: int) -> None:
        """
        remove a tab with the given ID.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def removeTabListener(self, Listener: XTabListener_a36e0b09) -> None:
        """
        unregister listener for inserting/removing tabs and changing their properties.
        """
        ...
    @abstractmethod
    def setTabProps(self, ID: int, Properties: typing.Tuple[NamedValue_a37a0af3, ...]) -> None:
        """
        change some properties of the specified tab.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...

__all__ = ['XSimpleTabController']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.graphic
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..geometry.real_rectangle2_d import RealRectangle2D as RealRectangle2D_d9b0e03
    from .x_primitive2_d import XPrimitive2D as XPrimitive2D_d5730c6d
    from ..rendering.x_bitmap import XBitmap as XBitmap_b1b70b7b

class XPrimitive2DRenderer(XInterface_8f010a43):
    """
    XPrimitive2DRenderer interface.
    
    This interface allows to convert from a sequence of XPrimitive2Ds to a XBitmap

    See Also:
        `API XPrimitive2DRenderer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1graphic_1_1XPrimitive2DRenderer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.graphic'
    __ooo_full_ns__: str = 'com.sun.star.graphic.XPrimitive2DRenderer'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.graphic.XPrimitive2DRenderer'

    @abstractmethod
    def rasterize(self, Primitive2DSequence: typing.Tuple[XPrimitive2D_d5730c6d, ...], aViewInformationSequence: typing.Tuple[PropertyValue_c9610c73, ...], DPIX: int, DPIY: int, Range: RealRectangle2D_d9b0e03, MaximumQuadraticPixels: int) -> XBitmap_b1b70b7b:
        """
        return rasterized version of given XPrimitive2D
        
        0
        
        is given, a horizontal default resolution of 72 DPI is used.
        
        0
        
        is given, a vertical default resolution of 72 DPI is used.
        """
        ...

__all__ = ['XPrimitive2DRenderer']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.container
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XHierarchicalNameAccess(XInterface_8f010a43):
    """
    is used to have hierarchical access to elements within a container.
    
    You address an object of a specific level in the hierarchy by giving its fully qualified name, e.g., \"com.sun.star.uno.XInterface\".
    
    To implement inaccurate name access, support the com.sun.star.beans.XExactName interface.

    See Also:
        `API XHierarchicalNameAccess <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1container_1_1XHierarchicalNameAccess.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.container'
    __ooo_full_ns__: str = 'com.sun.star.container.XHierarchicalNameAccess'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.container.XHierarchicalNameAccess'

    @abstractmethod
    def getByHierarchicalName(self, aName: str) -> object:
        """

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...
    @abstractmethod
    def hasByHierarchicalName(self, aName: str) -> bool:
        """
        In many cases, the next call is XNameAccess.getByName(). You should optimize this case.
        """
        ...

__all__ = ['XHierarchicalNameAccess']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.xml.dom
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class SAXDocumentBuilderState(metaclass=UnoEnumMeta, type_name="com.sun.star.xml.dom.SAXDocumentBuilderState", name_space="com.sun.star.xml.dom"):
        """Dynamically created class that represents ``com.sun.star.xml.dom.SAXDocumentBuilderState`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.xml.dom.SAXDocumentBuilderState import BUILDING_DOCUMENT as S_A_X_DOCUMENT_BUILDER_STATE_BUILDING_DOCUMENT
        from com.sun.star.xml.dom.SAXDocumentBuilderState import BUILDING_FRAGMENT as S_A_X_DOCUMENT_BUILDER_STATE_BUILDING_FRAGMENT
        from com.sun.star.xml.dom.SAXDocumentBuilderState import DOCUMENT_FINISHED as S_A_X_DOCUMENT_BUILDER_STATE_DOCUMENT_FINISHED
        from com.sun.star.xml.dom.SAXDocumentBuilderState import FRAGMENT_FINISHED as S_A_X_DOCUMENT_BUILDER_STATE_FRAGMENT_FINISHED
        from com.sun.star.xml.dom.SAXDocumentBuilderState import READY as S_A_X_DOCUMENT_BUILDER_STATE_READY

        class SAXDocumentBuilderState(uno.Enum):
            """
            Enum Class

            ENUM SAXDocumentBuilderState

            See Also:
                `API SAXDocumentBuilderState <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1xml_1_1dom.html#a8e1d723b2d19d95078879bf81b535b36>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.xml.dom.SAXDocumentBuilderState', value)

            __ooo_ns__: str = 'com.sun.star.xml.dom'
            __ooo_full_ns__: str = 'com.sun.star.xml.dom.SAXDocumentBuilderState'
            __ooo_type_name__: str = 'enum'

            BUILDING_DOCUMENT = S_A_X_DOCUMENT_BUILDER_STATE_BUILDING_DOCUMENT
            """
            """
            BUILDING_FRAGMENT = S_A_X_DOCUMENT_BUILDER_STATE_BUILDING_FRAGMENT
            """
            """
            DOCUMENT_FINISHED = S_A_X_DOCUMENT_BUILDER_STATE_DOCUMENT_FINISHED
            """
            """
            FRAGMENT_FINISHED = S_A_X_DOCUMENT_BUILDER_STATE_FRAGMENT_FINISHED
            """
            """
            READY = S_A_X_DOCUMENT_BUILDER_STATE_READY
            """
            """
    else:
        # keep document generators happy
        from ....lo.xml.dom.sax_document_builder_state import SAXDocumentBuilderState as SAXDocumentBuilderState


__all__ = ['SAXDocumentBuilderState']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class KCharacterType(metaclass=UnoConstMeta, type_name="com.sun.star.i18n.KCharacterType", name_space="com.sun.star.i18n"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.i18n.KCharacterType``"""
        pass

    class KCharacterTypeEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.i18n.KCharacterType", name_space="com.sun.star.i18n"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.i18n.KCharacterType`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.i18n import KCharacterType as KCharacterType
    else:
        # keep document generators happy
        from ...lo.i18n.k_character_type import KCharacterType as KCharacterType

    class KCharacterTypeEnum(IntEnum):
        """
        Enum of Const Class KCharacterType

        Constants to identify the character type.
        
        Returned by XCharacterClassification.getCharacterType() and XCharacterClassification.getStringType()
        """
        DIGIT = KCharacterType.DIGIT
        """
        digit
        """
        UPPER = KCharacterType.UPPER
        """
        upper case alpha letter
        """
        LOWER = KCharacterType.LOWER
        """
        lower case alpha letter
        """
        TITLE_CASE = KCharacterType.TITLE_CASE
        """
        title case alpha letter
        """
        ALPHA = KCharacterType.ALPHA
        """
        any alpha, ALPHA = UPPER | LOWER | TITLE_CASE
        """
        CONTROL = KCharacterType.CONTROL
        """
        control character
        """
        PRINTABLE = KCharacterType.PRINTABLE
        """
        printable character
        """
        BASE_FORM = KCharacterType.BASE_FORM
        """
        base form
        """
        LETTER = KCharacterType.LETTER
        """
        any UnicodeType...._LETTER.
        
        Note that a LETTER must not necessarily be ALPHA
        """

__all__ = ['KCharacterType', 'KCharacterTypeEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..awt.rectangle import Rectangle as Rectangle_84b109e9

class XDiagramPositioning(XInterface_8f010a43):
    """
    allow for different positioning options for a diagram

    See Also:
        `API XDiagramPositioning <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart_1_1XDiagramPositioning.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart'
    __ooo_full_ns__: str = 'com.sun.star.chart.XDiagramPositioning'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.chart.XDiagramPositioning'

    @abstractmethod
    def calculateDiagramPositionExcludingAxes(self) -> Rectangle_84b109e9:
        """
        """
        ...
    @abstractmethod
    def calculateDiagramPositionIncludingAxes(self) -> Rectangle_84b109e9:
        """
        """
        ...
    @abstractmethod
    def calculateDiagramPositionIncludingAxesAndAxisTitles(self) -> Rectangle_84b109e9:
        """
        """
        ...
    @abstractmethod
    def isAutomaticDiagramPositioning(self) -> bool:
        """
        """
        ...
    @abstractmethod
    def isExcludingDiagramPositioning(self) -> bool:
        """
        """
        ...
    @abstractmethod
    def setAutomaticDiagramPositioning(self) -> None:
        """
        the diagram will be placed automatically
        """
        ...
    @abstractmethod
    def setDiagramPositionExcludingAxes(self, PositionRect: Rectangle_84b109e9) -> None:
        """
        place the inner diagram part excluding any axes, labels and titles
        """
        ...
    @abstractmethod
    def setDiagramPositionIncludingAxes(self, PositionRect: Rectangle_84b109e9) -> None:
        """
        place the outer diagram part including the axes and axes labels, but excluding the axes titles.
        """
        ...
    @abstractmethod
    def setDiagramPositionIncludingAxesAndAxisTitles(self, PositionRect: Rectangle_84b109e9) -> None:
        """
        place the diagram including the axes, axes labels and axes titles.
        
        For the placement the current axis titles are taken into account, so the titles must be initialized properly before this method is called.
        """
        ...

__all__ = ['XDiagramPositioning']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .dde_item_info import DDEItemInfo as DDEItemInfo_ac870b09


class DDELinkInfo(object):
    """
    Struct Class

    describes all items of a DDE connection used in formulas.
    
    A DDE connection consists of the DDE service name, the DDE topic and a list of DDE items which may contain results cached from the last update.
    
    The formula that would need this information for example would contain =[1]!'R1C1' or =[2]!'Sheet1.A1' where [1] is an external link with DDE service name \"excel\" and the topic \"X:\\PATH\\[FILE.XLSX]Sheet1\", and [2] contains service \"soffice\" and topic \"file:///X:/PATH/FILE.ODS\". The service name is stored in DDELinkInfo.Service, the topic is stored in DDELinkInfo.Topic. Note that if the DDE item contains single quotes they are escaped by doubling them, as usual, for example =[2]!'''Sheet name''.A1' in a \"soffice\" service.
    
    **since**
    
        OOo 3.1

    See Also:
        `API DDELinkInfo <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sheet_1_1DDELinkInfo.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.DDELinkInfo'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.sheet.DDELinkInfo'
    """Literal Constant ``com.sun.star.sheet.DDELinkInfo``"""

    def __init__(self, Items: typing.Optional[typing.Tuple[DDEItemInfo_ac870b09, ...]] = (), Service: typing.Optional[str] = '', Topic: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Items (typing.Tuple[DDEItemInfo, ...], optional): Items value.
            Service (str, optional): Service value.
            Topic (str, optional): Topic value.
        """
        super().__init__()

        if isinstance(Items, DDELinkInfo):
            oth: DDELinkInfo = Items
            self.Items = oth.Items
            self.Service = oth.Service
            self.Topic = oth.Topic
            return

        kargs = {
            "Items": Items,
            "Service": Service,
            "Topic": Topic,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._items = kwargs["Items"]
        self._service = kwargs["Service"]
        self._topic = kwargs["Topic"]


    @property
    def Items(self) -> typing.Tuple[DDEItemInfo_ac870b09, ...]:
        """
        A list of DDE items.
        
        Each item may contain its results from the last update.
        """
        return self._items

    @Items.setter
    def Items(self, value: typing.Tuple[DDEItemInfo_ac870b09, ...]) -> None:
        self._items = value

    @property
    def Service(self) -> str:
        """
        The DDE service name.
        """
        return self._service

    @Service.setter
    def Service(self, value: str) -> None:
        self._service = value

    @property
    def Topic(self) -> str:
        """
        The DDE topic.
        """
        return self._topic

    @Topic.setter
    def Topic(self, value: str) -> None:
        self._topic = value


__all__ = ['DDELinkInfo']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.linguistic2
from __future__ import annotations
import typing
from abc import abstractmethod
from ..container.x_named import XNamed as XNamed_a6520b08
if typing.TYPE_CHECKING:
    from .x_dictionary_entry import XDictionaryEntry as XDictionaryEntry_49ef0ff5
    from .x_dictionary_event_listener import XDictionaryEventListener as XDictionaryEventListener_d74c132b
    from com.sun.star.linguistic2.DictionaryType import DictionaryTypeProto

class XDictionary1(XNamed_a6520b08):
    """
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XDictionary1 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XDictionary1.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.linguistic2'
    __ooo_full_ns__: str = 'com.sun.star.linguistic2.XDictionary1'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.linguistic2.XDictionary1'

    @abstractmethod
    def add(self, aWord: str, bIsNegative: bool, aRplcText: str) -> bool:
        """
        """
        ...
    @abstractmethod
    def addDictionaryEventListener(self, xListener: XDictionaryEventListener_d74c132b) -> bool:
        """
        """
        ...
    @abstractmethod
    def addEntry(self, xDicEntry: XDictionaryEntry_49ef0ff5) -> bool:
        """
        """
        ...
    @abstractmethod
    def clear(self) -> None:
        """
        """
        ...
    @abstractmethod
    def getCount(self) -> int:
        """
        """
        ...
    @abstractmethod
    def getDictionaryType(self) -> DictionaryTypeProto:
        """
        """
        ...
    @abstractmethod
    def getEntries(self) -> typing.Tuple[XDictionaryEntry_49ef0ff5, ...]:
        """
        """
        ...
    @abstractmethod
    def getEntry(self, aWord: str) -> XDictionaryEntry_49ef0ff5:
        """
        """
        ...
    @abstractmethod
    def getLanguage(self) -> int:
        """
        """
        ...
    @abstractmethod
    def isActive(self) -> bool:
        """
        """
        ...
    @abstractmethod
    def isFull(self) -> bool:
        """
        """
        ...
    @abstractmethod
    def remove(self, aWord: str) -> bool:
        """
        """
        ...
    @abstractmethod
    def removeDictionaryEventListener(self, xListener: XDictionaryEventListener_d74c132b) -> bool:
        """
        """
        ...
    @abstractmethod
    def setActive(self, bActivate: bool) -> None:
        """
        """
        ...
    @abstractmethod
    def setLanguage(self, nLang: int) -> None:
        """
        """
        ...

__all__ = ['XDictionary1']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart2
from __future__ import annotations
import typing
from abc import abstractproperty
from .chart_type import ChartType as ChartType_a2640ae0
if typing.TYPE_CHECKING:
    from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa

class CandleStickChartType(ChartType_a2640ae0):
    """
    Service Class

    chart type service for candlestick charts.

    See Also:
        `API CandleStickChartType <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart2_1_1CandleStickChartType.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart2'
    __ooo_full_ns__: str = 'com.sun.star.chart2.CandleStickChartType'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def BlackDay(self) -> XPropertySet_bc180bfa:
        """
        If the candlestick chart shows Japanese candlesticks, that is the property Japanese is TRUE, the property set given here contains the formatting attributes of the black boxes, i.e.
        
        the boxes shown for falling values.
        
        The com.sun.star.beans.XPropertySet given here must support the services com.sun.star.drawing.FillProperties and com.sun.star.drawing.LineProperties.
        """
        ...

    @abstractproperty
    def Japanese(self) -> bool:
        """
        If this property is TRUE, the candlesticks are shown as Japanese candlesticks.
        
        This implies that the property ShowFirst is also TRUE.
        
        Japanese candlesticks show the first and last value as boxes. A rising course (i.e. if the last value is greater than the first one) is shown by a white box. A falling course is shown by a black box.
        
        Default is FALSE.
        """
        ...

    @abstractproperty
    def ShowFirst(self) -> bool:
        """
        If this property is TRUE, the first value (which would be the opening course in a stock chart) is shown in the chart.
        
        This also makes the role \"values-first\" mandatory.
        
        This property is only evaluated for non-Japanese candlestick charts, as Japanese candlesticks always require to show the first value.
        
        Default is FALSE.
        """
        ...

    @abstractproperty
    def ShowHighLow(self) -> bool:
        """
        If this property is TRUE, the low and high values are shown in the chart.
        
        This also makes the roles \"values-min\" and \"values-max\" mandatory.
        
        Default is TRUE.
        """
        ...

    @abstractproperty
    def WhiteDay(self) -> XPropertySet_bc180bfa:
        """
        If the candlestick chart shows Japanese candlesticks, that is the property Japanese is TRUE, the property set given here contains the formatting attributes of the white boxes, i.e.
        
        the boxes shown for rising values.
        
        The com.sun.star.beans.XPropertySet given here must support the services com.sun.star.drawing.FillProperties and com.sun.star.drawing.LineProperties.
        """
        ...


__all__ = ['CandleStickChartType']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.bridge.oleautomation
from __future__ import annotations
from ...uno.x_interface import XInterface as XInterface_8f010a43

class XAutomationObject(XInterface_8f010a43):
    """
    a tagging interface for UNO objects which represent Automation objects.
    
    If an Automation object is bridged into the UNO environment, then the resulting UNO object does not distinguish itself from any other ordinary UNO object. However, it may be desirable to have that distinction regardless, if a UNO client needs to take particular Automation specific characteristics into account. By providing XAutomationObject an object declares to be representing an Automation object.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XAutomationObject <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1bridge_1_1oleautomation_1_1XAutomationObject.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.bridge.oleautomation'
    __ooo_full_ns__: str = 'com.sun.star.bridge.oleautomation.XAutomationObject'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.bridge.oleautomation.XAutomationObject'


__all__ = ['XAutomationObject']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.reflection
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_idl_class import XIdlClass as XIdlClass_d63a0c9a

class XIdlReflection(XInterface_8f010a43):
    """
    Interface to reflect types.

    See Also:
        `API XIdlReflection <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlReflection.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.reflection'
    __ooo_full_ns__: str = 'com.sun.star.reflection.XIdlReflection'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.reflection.XIdlReflection'

    @abstractmethod
    def forName(self, aTypeName: str) -> XIdlClass_d63a0c9a:
        """
        Obtaining a reflection interface for a type.
        
        You specify the type by its name. If the given type name can not be reflected, then a null-reference is returned.
        """
        ...
    @abstractmethod
    def getType(self, aObj: object) -> XIdlClass_d63a0c9a:
        """
        Obtaining a reflection interface for an object.
        
        This method takes the type of the object the any contains into account. If the any contains no object, then a null-reference is returned.
        """
        ...

__all__ = ['XIdlReflection']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.configuration.backend
# Libre Office Version: 7.4
import uno
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:

    def _get_class():
        orig_init = None
        ordered_keys = ('Message', 'Context', 'TargetException')
        def init(self, *args, **kwargs):
            if len(kwargs) == 0 and len(args) == 1 and getattr(args[0], "__class__", None) == self.__class__:
                orig_init(self, args[0])
                return
            kargs = kwargs.copy()
            for i, arg in enumerate(args):
                kargs[ordered_keys[i]] = arg
            orig_init(self, **kargs)

        type_name = 'com.sun.star.configuration.backend.InsufficientAccessRightsException'
        ex = uno.getClass(type_name)
        ex.__ooo_ns__ = 'com.sun.star.configuration.backend'
        ex.__ooo_full_ns__= type_name
        ex.__ooo_type_name__ = 'exception'
        orig_init = ex.__init__
        ex.__init__ = init
        return ex

    InsufficientAccessRightsException = _get_class()

else:
    if TYPE_CHECKING:
        from com.sun.star.configuration.backend import InsufficientAccessRightsException as InsufficientAccessRightsException
    else:
        from ....lo.configuration.backend.insufficient_access_rights_exception import InsufficientAccessRightsException as InsufficientAccessRightsException

__all__ = ['InsufficientAccessRightsException']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractmethod
from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6
if typing.TYPE_CHECKING:
    from .x_data_pilot_descriptor import XDataPilotDescriptor as XDataPilotDescriptor_27650f1a
    from ..table.cell_address import CellAddress as CellAddress_ae5f0b56

class XDataPilotTables(XNameAccess_e2ab0cf6):
    """
    provides access to the data pilot tables via name and inserting and removing data pilot tables.
    
    This interface extends the interface com.sun.star.container.XNameAccess which provides access to existing data pilot tables in the collection.

    See Also:
        `API XDataPilotTables <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XDataPilotTables.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.XDataPilotTables'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sheet.XDataPilotTables'

    @abstractmethod
    def createDataPilotDescriptor(self) -> XDataPilotDescriptor_27650f1a:
        """
        creates a data pilot descriptor.
        
        This descriptor can be used with XDataPilotTables.addTable().
        """
        ...
    @abstractmethod
    def insertNewByName(self, aName: str, OutputAddress: CellAddress_ae5f0b56, xDescriptor: XDataPilotDescriptor_27650f1a) -> None:
        """
        creates a new data pilot table and adds it to the collection.
        """
        ...
    @abstractmethod
    def removeByName(self, aName: str) -> None:
        """
        deletes a data pilot table from the collection.
        """
        ...

__all__ = ['XDataPilotTables']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text


class UserDataPart(object):
    """
    Const Class

    These constants define which part of the user data is displayed in a user data text field (service \"sun.one.text.TextField.ExtendedUser\")

    See Also:
        `API UserDataPart <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1text_1_1UserDataPart.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.UserDataPart'
    __ooo_type_name__: str = 'const'

    COMPANY = 0
    """
    The field shows the company name.
    """
    FIRSTNAME = 1
    """
    The field shows the first name.
    """
    NAME = 2
    """
    The field shows the name.
    """
    SHORTCUT = 3
    """
    The field shows the initials.
    """
    STREET = 4
    """
    The field shows the street.
    """
    COUNTRY = 5
    """
    The field shows the country.
    """
    ZIP = 6
    """
    The field shows the zip code.
    """
    CITY = 7
    """
    The field shows the city.
    """
    TITLE = 8
    """
    The field shows the title.
    """
    POSITION = 9
    """
    The field shows the position.
    """
    PHONE_PRIVATE = 10
    """
    The field shows the no of the private phone.
    """
    PHONE_COMPANY = 11
    """
    The field shows the number of the business phone.
    """
    FAX = 12
    """
    The field shows the fax no.
    """
    EMAIL = 13
    """
    The field shows the e-Mail.
    """
    STATE = 14
    """
    The field shows the state.
    """

__all__ = ['UserDataPart']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb
from __future__ import annotations
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from ..lang.x_component import XComponent as XComponent_98dc0ab5

class XSubDocument(ABC):
    """
    allows operating on a sub document of an OfficeDatabaseDocument
    
    **since**
    
        OOo 3.1

    See Also:
        `API XSubDocument <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdb_1_1XSubDocument.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.XSubDocument'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdb.XSubDocument'

    @abstractmethod
    def close(self) -> bool:
        """
        closes the sub document, if it had previously been opened in either mode

        Raises:
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def open(self) -> XComponent_98dc0ab5:
        """
        opens the sub document
        
        Note that opening the document means it is displayed in an own top-level frame on the desktop.

        Raises:
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def openDesign(self) -> XComponent_98dc0ab5:
        """
        opens the sub document in design mode

        Raises:
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def store(self) -> None:
        """
        stores the sub document, if it had previously been opened in either mode

        Raises:
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...

__all__ = ['XSubDocument']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .parse_result import ParseResult as ParseResult_9ea00ac2
    from ..lang.locale import Locale as Locale_70d308fa

class XCharacterClassification(XInterface_8f010a43):
    """
    Character classification (upper, lower, digit, letter, number, ...) and generic Unicode enabled parser.

    See Also:
        `API XCharacterClassification <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1i18n_1_1XCharacterClassification.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.XCharacterClassification'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.i18n.XCharacterClassification'

    @abstractmethod
    def getCharacterDirection(self, aText: str, nPos: int) -> int:
        """
        Get DirectionProperty of character at position nPos.
        """
        ...
    @abstractmethod
    def getCharacterType(self, aText: str, nPos: int, aLocale: Locale_70d308fa) -> int:
        """
        Get KCharacterType of character at position nPos.
        """
        ...
    @abstractmethod
    def getScript(self, aText: str, nPos: int) -> int:
        """
        Get UnicodeScript of character at position nPos.
        """
        ...
    @abstractmethod
    def getStringType(self, aText: str, nPos: int, nCount: int, aLocale: Locale_70d308fa) -> int:
        """
        Get accumulated KCharacterTypes of string starting at position nPos of length nCount code points.
        """
        ...
    @abstractmethod
    def getType(self, aText: str, nPos: int) -> int:
        """
        Get UnicodeType of character at position nPos.
        """
        ...
    @abstractmethod
    def parseAnyToken(self, aText: str, nPos: int, aLocale: Locale_70d308fa, nStartCharFlags: int, aUserDefinedCharactersStart: str, nContCharFlags: int, aUserDefinedCharactersCont: str) -> ParseResult_9ea00ac2:
        """
        Parse a string for a token starting at position nPos.
        
        A name or identifier must match the KParseTokens criteria passed in nStartCharFlags and nContCharFlags and may additionally contain characters of aUserDefinedCharactersStart and/or aUserDefinedCharactersCont.
        
        If a token may represent either a numeric value or a name according to the passed Start/Cont-Flags/Chars, both KParseType.ASC_NUM (or KParseType.UNI_NUM) and KParseType.IDENTNAME are set in ParseResult.TokenType.
        """
        ...
    @abstractmethod
    def parsePredefinedToken(self, nTokenType: int, aText: str, nPos: int, aLocale: Locale_70d308fa, nStartCharFlags: int, aUserDefinedCharactersStart: str, nContCharFlags: int, aUserDefinedCharactersCont: str) -> ParseResult_9ea00ac2:
        """
        Parse a string for a token of type nTokenType starting at position nPos.
        
        Other parameters are the same as in parseAnyToken(). If the actual token does not match the passed nTokenType a ParseResult.TokenType set to 0 (zero) is returned.
        """
        ...
    @abstractmethod
    def toLower(self, aText: str, nPos: int, nCount: int, aLocale: Locale_70d308fa) -> str:
        """
        Convert upper case alpha to lower case alpha, starting at position nPos for nCount code points.
        """
        ...
    @abstractmethod
    def toTitle(self, aText: str, nPos: int, nCount: int, aLocale: Locale_70d308fa) -> str:
        """
        Convert to title case, starting at position nPos for nCount code points.
        """
        ...
    @abstractmethod
    def toUpper(self, aText: str, nPos: int, nCount: int, aLocale: Locale_70d308fa) -> str:
        """
        Convert lower case alpha to upper case alpha, starting at position nPos for nCount code points.
        """
        ...

__all__ = ['XCharacterClassification']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb
from __future__ import annotations
from ..container.x_container import XContainer as XContainer_d6fb0cc6
from ..container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6
from ..lang.x_single_service_factory import XSingleServiceFactory as XSingleServiceFactory_27210f0d
from .x_database_registrations import XDatabaseRegistrations as XDatabaseRegistrations_25c20f1c
from ..uno.x_naming_service import XNamingService as XNamingService_bb9a0bdd

class XDatabaseContext(XContainer_d6fb0cc6, XEnumerationAccess_4bac0ffc, XNameAccess_e2ab0cf6, XSingleServiceFactory_27210f0d, XDatabaseRegistrations_25c20f1c, XNamingService_bb9a0bdd):
    """
    Provides an interface for the new-style DatabaseContext service to implement.
    
    **since**
    
        LibreOffice 4.0

    See Also:
        `API XDatabaseContext <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseContext.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.XDatabaseContext'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdb.XDatabaseContext'


__all__ = ['XDatabaseContext']

